import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { ResourceGroupsTaggingAPIServiceException as __BaseException } from "./ResourceGroupsTaggingAPIServiceException";

export interface ComplianceDetails {
    
    NoncompliantKeys?: string[];
    
    KeysWithNoncompliantValues?: string[];
    
    ComplianceStatus?: boolean;
}
export declare namespace ComplianceDetails {
    
    const filterSensitiveLog: (obj: ComplianceDetails) => any;
}

export declare class ConcurrentModificationException extends __BaseException {
    readonly name: "ConcurrentModificationException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConcurrentModificationException, __BaseException>);
}

export declare class ConstraintViolationException extends __BaseException {
    readonly name: "ConstraintViolationException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConstraintViolationException, __BaseException>);
}
export interface DescribeReportCreationInput {
}
export declare namespace DescribeReportCreationInput {
    
    const filterSensitiveLog: (obj: DescribeReportCreationInput) => any;
}
export interface DescribeReportCreationOutput {
    
    Status?: string;
    
    S3Location?: string;
    
    StartDate?: string;
    
    ErrorMessage?: string;
}
export declare namespace DescribeReportCreationOutput {
    
    const filterSensitiveLog: (obj: DescribeReportCreationOutput) => any;
}

export declare class InternalServiceException extends __BaseException {
    readonly name: "InternalServiceException";
    readonly $fault: "server";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InternalServiceException, __BaseException>);
}

export declare class InvalidParameterException extends __BaseException {
    readonly name: "InvalidParameterException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InvalidParameterException, __BaseException>);
}

export declare class ThrottledException extends __BaseException {
    readonly name: "ThrottledException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ThrottledException, __BaseException>);
}
export declare enum ErrorCode {
    INTERNAL_SERVICE_EXCEPTION = "InternalServiceException",
    INVALID_PARAMETER_EXCEPTION = "InvalidParameterException"
}

export interface FailureInfo {
    
    StatusCode?: number;
    
    ErrorCode?: ErrorCode | string;
    
    ErrorMessage?: string;
}
export declare namespace FailureInfo {
    
    const filterSensitiveLog: (obj: FailureInfo) => any;
}
export declare enum GroupByAttribute {
    REGION = "REGION",
    RESOURCE_TYPE = "RESOURCE_TYPE",
    TARGET_ID = "TARGET_ID"
}
export interface GetComplianceSummaryInput {
    
    TargetIdFilters?: string[];
    
    RegionFilters?: string[];
    
    ResourceTypeFilters?: string[];
    
    TagKeyFilters?: string[];
    
    GroupBy?: (GroupByAttribute | string)[];
    
    MaxResults?: number;
    
    PaginationToken?: string;
}
export declare namespace GetComplianceSummaryInput {
    
    const filterSensitiveLog: (obj: GetComplianceSummaryInput) => any;
}
export declare enum TargetIdType {
    ACCOUNT = "ACCOUNT",
    OU = "OU",
    ROOT = "ROOT"
}

export interface Summary {
    
    LastUpdated?: string;
    
    TargetId?: string;
    
    TargetIdType?: TargetIdType | string;
    
    Region?: string;
    
    ResourceType?: string;
    
    NonCompliantResources?: number;
}
export declare namespace Summary {
    
    const filterSensitiveLog: (obj: Summary) => any;
}
export interface GetComplianceSummaryOutput {
    
    SummaryList?: Summary[];
    
    PaginationToken?: string;
}
export declare namespace GetComplianceSummaryOutput {
    
    const filterSensitiveLog: (obj: GetComplianceSummaryOutput) => any;
}

export interface TagFilter {
    
    Key?: string;
    
    Values?: string[];
}
export declare namespace TagFilter {
    
    const filterSensitiveLog: (obj: TagFilter) => any;
}
export interface GetResourcesInput {
    
    PaginationToken?: string;
    
    TagFilters?: TagFilter[];
    
    ResourcesPerPage?: number;
    
    TagsPerPage?: number;
    
    ResourceTypeFilters?: string[];
    
    IncludeComplianceDetails?: boolean;
    
    ExcludeCompliantResources?: boolean;
    
    ResourceARNList?: string[];
}
export declare namespace GetResourcesInput {
    
    const filterSensitiveLog: (obj: GetResourcesInput) => any;
}

export interface Tag {
    
    Key: string | undefined;
    
    Value: string | undefined;
}
export declare namespace Tag {
    
    const filterSensitiveLog: (obj: Tag) => any;
}

export interface ResourceTagMapping {
    
    ResourceARN?: string;
    
    Tags?: Tag[];
    
    ComplianceDetails?: ComplianceDetails;
}
export declare namespace ResourceTagMapping {
    
    const filterSensitiveLog: (obj: ResourceTagMapping) => any;
}
export interface GetResourcesOutput {
    
    PaginationToken?: string;
    
    ResourceTagMappingList?: ResourceTagMapping[];
}
export declare namespace GetResourcesOutput {
    
    const filterSensitiveLog: (obj: GetResourcesOutput) => any;
}

export declare class PaginationTokenExpiredException extends __BaseException {
    readonly name: "PaginationTokenExpiredException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<PaginationTokenExpiredException, __BaseException>);
}
export interface GetTagKeysInput {
    
    PaginationToken?: string;
}
export declare namespace GetTagKeysInput {
    
    const filterSensitiveLog: (obj: GetTagKeysInput) => any;
}
export interface GetTagKeysOutput {
    
    PaginationToken?: string;
    
    TagKeys?: string[];
}
export declare namespace GetTagKeysOutput {
    
    const filterSensitiveLog: (obj: GetTagKeysOutput) => any;
}
export interface GetTagValuesInput {
    
    PaginationToken?: string;
    
    Key: string | undefined;
}
export declare namespace GetTagValuesInput {
    
    const filterSensitiveLog: (obj: GetTagValuesInput) => any;
}
export interface GetTagValuesOutput {
    
    PaginationToken?: string;
    
    TagValues?: string[];
}
export declare namespace GetTagValuesOutput {
    
    const filterSensitiveLog: (obj: GetTagValuesOutput) => any;
}
export interface StartReportCreationInput {
    
    S3Bucket: string | undefined;
}
export declare namespace StartReportCreationInput {
    
    const filterSensitiveLog: (obj: StartReportCreationInput) => any;
}
export interface StartReportCreationOutput {
}
export declare namespace StartReportCreationOutput {
    
    const filterSensitiveLog: (obj: StartReportCreationOutput) => any;
}
export interface TagResourcesInput {
    
    ResourceARNList: string[] | undefined;
    
    Tags: {
        [key: string]: string;
    } | undefined;
}
export declare namespace TagResourcesInput {
    
    const filterSensitiveLog: (obj: TagResourcesInput) => any;
}
export interface TagResourcesOutput {
    
    FailedResourcesMap?: {
        [key: string]: FailureInfo;
    };
}
export declare namespace TagResourcesOutput {
    
    const filterSensitiveLog: (obj: TagResourcesOutput) => any;
}
export interface UntagResourcesInput {
    
    ResourceARNList: string[] | undefined;
    
    TagKeys: string[] | undefined;
}
export declare namespace UntagResourcesInput {
    
    const filterSensitiveLog: (obj: UntagResourcesInput) => any;
}
export interface UntagResourcesOutput {
    
    FailedResourcesMap?: {
        [key: string]: FailureInfo;
    };
}
export declare namespace UntagResourcesOutput {
    
    const filterSensitiveLog: (obj: UntagResourcesOutput) => any;
}
